@@ -1,15 +1,20 @@
-import collections
 import xml.sax
 
+import cobble
 
-XmlElementBase = collections.namedtuple("XmlElement", ["name", "attributes", "children"])
-class XmlElement(XmlElementBase):
+
+@cobble.data
+class XmlElement(object):
+    name = cobble.field()
+    attributes = cobble.field()
+    children = cobble.field()
+    
     def find_child_or_null(self, name):
         return self.find_child(name) or _null_xml_element
     
     def find_child(self, name):
         for child in self.children:
-            if child.name == name:
+            if isinstance(child, XmlElement) and child.name == name:
                 return child
         
     
@@ -48,7 +53,9 @@ class NullXmlElement(object):
 _null_xml_element = NullXmlElement()
 
 
-XmlText = collections.namedtuple("XmlText", ["value"])
+@cobble.data
+class XmlText(object):
+    value = cobble.field()
 
 
 def element(name, attributes=None, children=None):
